@@ -214,8 +214,9 @@ class CustomValidator(Criterion):
 
 
 class RequestValidator:
-    def __init__(self, nobody=None, fields=None):
+    def __init__(self, nobody=None, fields=None, strict=False):
         self.nobody = nobody
+        self.strict = strict
 
         self.fields = {}
         if not fields:
@@ -235,6 +236,14 @@ class RequestValidator:
         if self.nobody and request.contentlength:
             raise statuses.status(400, 'Body Not Allowed')
 
+        if self.strict:
+            extrafields = set(request.form.keys()) - set(self.fields.keys())
+            if extrafields:
+                raise statuses.status(
+                    400,
+                    f'Invalid field(s): {", ".join(extrafields)}'
+                )
+
         for name, field in self.fields.items():
 
             if request.query and name in request.query:
